#[repr(u8)]pub enum GroupMemberPointerInstruction {
Initialize = 0,
Update = 1,
}Expand description
Group member pointer extension instructions
Variants
Initialize = 0
Initialize a new mint with a group member pointer
Fails if the mint has already been initialized, so must be called before
InitializeMint.
The mint must have exactly enough space allocated for the base mint (82 bytes), plus 83 bytes of padding, 1 byte reserved for the account type, then space required for this extension, plus any others.
Accounts expected by this instruction:
[writable]The mint to initialize.
Data expected by this instruction:
crate::extension::group_member_pointer::instruction::InitializeInstructionData
Update = 1
Update the group member pointer address. Only supported for mints that
include the GroupMemberPointer extension.
Accounts expected by this instruction:
- Single authority
[writable]The mint.[signer]The group member pointer authority.
- Multisignature authority
[writable]The mint.[]The group member pointer authority...2+M[signer]M signer accounts.
Data expected by this instruction:
crate::extension::group_member_pointer::instruction::UpdateInstructionData