#[repr(u8)]pub enum MetadataPointerInstruction {
Initialize = 0,
Update = 1,
}Expand description
Metadata pointer extension instructions
Variants
Initialize = 0
Initialize a new mint with a metadata pointer
Fails if the mint has already been initialized, so must be called before
InitializeMint.
The mint must have exactly enough space allocated for the base mint (82 bytes), plus 83 bytes of padding, 1 byte reserved for the account type, then space required for this extension, plus any others.
Accounts expected by this instruction:
[writable]The mint to initialize.
Data expected by this instruction:
crate::extension::metadata_pointer::instruction::InitializeInstructionData
Update = 1
Update the metadata pointer address. Only supported for mints that
include the MetadataPointer extension.
Accounts expected by this instruction:
- Single authority
[writable]The mint.[signer]The metadata pointer authority.
- Multisignature authority
[writable]The mint.[]The mint’s metadata pointer authority...2+M[signer]M signer accounts.
Data expected by this instruction:
crate::extension::metadata_pointer::instruction::UpdateInstructionData