PausableConfig

Struct PausableConfig 

#[repr(C)]
pub struct PausableConfig { pub authority: MaybeNull<Address>, pub paused: Bool, }
Indicates that the tokens from this mint can be paused

Fields

authority: MaybeNull<Address>

Authority that can pause or resume activity on the mint

paused: Bool

Whether minting / transferring / burning tokens is paused