TransferFeeAmount

Struct TransferFeeAmount 

#[repr(C)]
pub struct TransferFeeAmount { pub withheld_amount: U64, }
Transfer fee extension data for accounts.

Fields

withheld_amount: U64

Amount withheld during transfers, to be harvested to the mint

Implementations

Source

impl TransferFeeAmount

pub fn closable(&self) -> ProgramResult

Check if the extension is in a closable state