TransferFeeConfig

Struct TransferFeeConfig 

#[repr(C)]
pub struct TransferFeeConfig { pub transfer_fee_config_authority: MaybeNull<Address>, pub withdraw_withheld_authority: MaybeNull<Address>, pub withheld_amount: U64, pub older_transfer_fee: TransferFee, pub newer_transfer_fee: TransferFee, }
Transfer fee extension data for mints.

Fields

transfer_fee_config_authority: MaybeNull<Address>

Optional authority to set the fee

withdraw_withheld_authority: MaybeNull<Address>

Withdraw from mint instructions must be signed by this key

withheld_amount: U64

Withheld transfer fee tokens that have been moved to the mint for withdrawal

older_transfer_fee: TransferFee

Older transfer fee, used if current epoch < new_transfer_fee.epoch

newer_transfer_fee: TransferFee

Newer transfer fee, used if current epoch >= new_transfer_fee.epoch

Implementations

Source

impl TransferFeeConfig

pub fn get_epoch_fee(&self, epoch: u64) -> &TransferFee

Get the fee for the given epoch

pub fn calculate_epoch_fee( &self, epoch: u64, pre_fee_amount: u64, ) -> Option<u64>

Calculate the fee for the given epoch and input amount

pub fn calculate_inverse_epoch_fee( &self, epoch: u64, post_fee_amount: u64, ) -> Option<u64>

Calculate the fee for the given epoch and output amount