#[repr(transparent)]pub struct TransferHookAccount {
pub transferring: Bool,
}Expand description
Indicates that the tokens from this account belong to a mint with a transfer hook
Fields
transferring: BoolFlag to indicate that the account is in the middle of a transfer