PodAccount

Struct PodAccount 

#[repr(C)]
pub struct PodAccount { pub mint: Address, pub owner: Address, pub amount: U64, pub delegate: PodCOption<Address>, pub state: u8, pub is_native: PodCOption<U64>, pub delegated_amount: U64, pub close_authority: PodCOption<Address>, }
crate::state::Account data stored as a Pod type

Fields

mint: Address

The mint associated with this account

owner: Address

The owner of this account.

amount: U64

The amount of tokens this account holds.

delegate: PodCOption<Address>

If delegate is Some then delegated_amount represents the amount authorized by the delegate

state: u8

The account’s AccountState, stored as a u8

is_native: PodCOption<U64>

If is_some, this is a native token, and the value logs the rent-exempt reserve. An Account is required to be rent-exempt, so the value is used by the Processor to ensure that wrapped SOL accounts do not drop below this threshold.

delegated_amount: U64

The amount delegated

close_authority: PodCOption<Address>

Optional authority to close the account.

Implementations

Source

impl PodAccount

pub fn is_frozen(&self) -> bool

Checks if account is frozen

pub fn is_native(&self) -> bool

Checks if account is native

pub fn is_owned_by_system_program_or_incinerator(&self) -> bool

Checks if a token Account’s owner is the system_program or the incinerator