#[repr(C, packed(1))]pub struct PodCOption<T>{
pub option: [u8; 4],
pub value: T,
}Expand description
COption<T> stored as a Pod type
Fields
option: [u8; 4]Whether a value is set
value: TThe value
Implementations
Sourceimpl<T> PodCOption<T>
impl<T> PodCOption<T>
Sourcepub const SOME: [u8; 4]
pub const SOME: [u8; 4]
Represents that some value is stored in the option, like
Option::Some(v)
Sourcepub fn none() -> Self
pub fn none() -> Self
Create a PodCOption equivalent of Option::None
This could be made const by using core::mem::zeroed, but that would
require unsafe code, which is prohibited at the crate level.