PodMint

Struct PodMint 

#[repr(C)]
pub struct PodMint { pub mint_authority: PodCOption<Address>, pub supply: U64, pub decimals: u8, pub is_initialized: Bool, pub freeze_authority: PodCOption<Address>, }
crate::state::Mint data stored as a Pod type

Fields

mint_authority: PodCOption<Address>

Optional authority used to mint new tokens. The mint authority may only be provided during mint creation. If no mint authority is present then the mint has a fixed supply and no further tokens may be minted.

supply: U64

Total supply of tokens.

decimals: u8

Number of base 10 digits to the right of the decimal place.

is_initialized: Bool

If true, this structure has been initialized

freeze_authority: PodCOption<Address>

Optional authority to freeze token accounts.