#[repr(C)]pub struct ZeroCiphertextProofData {
pub context: ZeroCiphertextProofContext,
pub proof: PodZeroCiphertextProof,
}Expand description
The instruction data that is needed for the ProofInstruction::VerifyZeroCiphertext instruction.
It includes the cryptographic proof as well as the context data information needed to verify the proof.
Fields
context: ZeroCiphertextProofContextThe context data for the zero-ciphertext proof
proof: PodZeroCiphertextProofProof that the ciphertext is zero