#[repr(C)]pub struct TransferFeeAmount {
pub withheld_amount: U64,
}Expand description
Transfer fee extension data for accounts.
Fields
withheld_amount: U64Amount withheld during transfers, to be harvested to the mint
Implementations
Sourceimpl TransferFeeAmount
impl TransferFeeAmount
Sourcepub fn closable(&self) -> ProgramResult
pub fn closable(&self) -> ProgramResult
Check if the extension is in a closable state